@@ -1,9 +1,8 @@
-import django
-from django.views.generic.base import ContextMixin
-from django.views.generic.edit import FormView, ModelFormMixin
-from django.views.generic.detail import SingleObjectTemplateResponseMixin
-from django.http import HttpResponseRedirect
+from django.contrib import messages
 from django.forms.formsets import all_valid
+from django.views.generic.base import ContextMixin
+from django.views.generic.detail import SingleObjectTemplateResponseMixin
+from django.views.generic.edit import FormView, ModelFormMixin
 
 from extra_views.formsets import BaseInlineFormSetFactory
 
@@ -37,8 +36,12 @@ class InlineFormSetFactory(BaseInlineFormSetFactory):
 class InlineFormSet(InlineFormSetFactory):
     def __init__(self, *args, **kwargs):
         from warnings import warn
-        warn('`extra_views.InlineFormSet` has been renamed to `InlineFormSetFactory`. '
-             '`InlineFormSet` will be removed in a future release.', DeprecationWarning)
+
+        warn(
+            "`extra_views.InlineFormSet` has been renamed to `InlineFormSetFactory`. "
+            "`InlineFormSet` will be removed in a future release.",
+            DeprecationWarning,
+        )
         super(InlineFormSet, self).__init__(*args, **kwargs)
 
 
@@ -49,6 +52,7 @@ class ModelFormWithInlinesMixin(ModelFormMixin):
 
     The inlines should be subclasses of `InlineFormSetFactory`.
     """
+
     inlines = []
 
     def get_inlines(self):
@@ -61,17 +65,19 @@ class ModelFormWithInlinesMixin(ModelFormMixin):
         """
         If the form and formsets are valid, save the associated models.
         """
-        self.object = form.save()
+        response = self.form_valid(form)
         for formset in inlines:
             formset.save()
-        return HttpResponseRedirect(self.get_success_url())
+        return response
 
     def forms_invalid(self, form, inlines):
         """
         If the form or formsets are invalid, re-render the context data with the
         data-filled form and formsets and errors.
         """
-        return self.render_to_response(self.get_context_data(form=form, inlines=inlines))
+        return self.render_to_response(
+            self.get_context_data(form=form, inlines=inlines)
+        )
 
     def construct_inlines(self):
         """
@@ -79,7 +85,9 @@ class ModelFormWithInlinesMixin(ModelFormMixin):
         """
         inline_formsets = []
         for inline_class in self.get_inlines():
-            inline_instance = inline_class(self.model, self.request, self.object, self.kwargs, self)
+            inline_instance = inline_class(
+                self.model, self.request, self.object, self.kwargs, self
+            )
             inline_formset = inline_instance.construct_formset()
             inline_formsets.append(inline_formset)
         return inline_formsets
@@ -97,16 +105,19 @@ class ProcessFormWithInlinesView(FormView):
         form_class = self.get_form_class()
         form = self.get_form(form_class)
         inlines = self.construct_inlines()
-        return self.render_to_response(self.get_context_data(form=form, inlines=inlines, **kwargs))
+        return self.render_to_response(
+            self.get_context_data(form=form, inlines=inlines, **kwargs)
+        )
 
     def post(self, request, *args, **kwargs):
         """
-        Handles POST requests, instantiating a form and formset instances with the passed
-        POST variables and then checked for validity.
+        Handles POST requests, instantiating a form and formset instances with the
+        passed POST variables and then checked for validity.
         """
         form_class = self.get_form_class()
         form = self.get_form(form_class)
 
+        initial_object = self.object
         if form.is_valid():
             self.object = form.save(commit=False)
             form_validated = True
@@ -117,6 +128,7 @@ class ProcessFormWithInlinesView(FormView):
 
         if all_valid(inlines) and form_validated:
             return self.forms_valid(form, inlines)
+        self.object = initial_object
         return self.forms_invalid(form, inlines)
 
     # PUT is a valid HTTP verb for creating (with a known URL) or editing an
@@ -141,12 +153,15 @@ class BaseCreateWithInlinesView(ModelFormWithInlinesMixin, ProcessFormWithInline
         return super(BaseCreateWithInlinesView, self).post(request, *args, **kwargs)
 
 
-class CreateWithInlinesView(SingleObjectTemplateResponseMixin, BaseCreateWithInlinesView):
+class CreateWithInlinesView(
+    SingleObjectTemplateResponseMixin, BaseCreateWithInlinesView
+):
     """
     View for creating a new object instance with related model instances,
     with a response rendered by template.
     """
-    template_name_suffix = '_form'
+
+    template_name_suffix = "_form"
 
 
 class BaseUpdateWithInlinesView(ModelFormWithInlinesMixin, ProcessFormWithInlinesView):
@@ -165,12 +180,15 @@ class BaseUpdateWithInlinesView(ModelFormWithInlinesMixin, ProcessFormWithInline
         return super(BaseUpdateWithInlinesView, self).post(request, *args, **kwargs)
 
 
-class UpdateWithInlinesView(SingleObjectTemplateResponseMixin, BaseUpdateWithInlinesView):
+class UpdateWithInlinesView(
+    SingleObjectTemplateResponseMixin, BaseUpdateWithInlinesView
+):
     """
     View for updating an object with related model instances,
     with a response rendered by template.
     """
-    template_name_suffix = '_form'
+
+    template_name_suffix = "_form"
 
 
 class NamedFormsetsMixin(ContextMixin):
@@ -178,6 +196,7 @@ class NamedFormsetsMixin(ContextMixin):
     A mixin for use with `CreateWithInlinesView` or `UpdateWithInlinesView` that lets
     you define the context variable for each inline.
     """
+
     inlines_names = []
 
     def get_inlines_names(self):
@@ -196,8 +215,52 @@ class NamedFormsetsMixin(ContextMixin):
 
         if inlines_names:
             # We have formset or inlines in context, but never both
-            context.update(zip(inlines_names, kwargs.get('inlines', [])))
-            if 'formset' in kwargs:
-                context[inlines_names[0]] = kwargs['formset']
+            context.update(zip(inlines_names, kwargs.get("inlines", [])))
+            if "formset" in kwargs:
+                context[inlines_names[0]] = kwargs["formset"]
         context.update(kwargs)
         return super(NamedFormsetsMixin, self).get_context_data(**context)
+
+
+class SuccessMessageMixin(object):
+    """
+    Adds success message on views with inlines if django.contrib.messages framework
+    is used.
+    In order to use just add mixin in to inheritance before main class, e.g.:
+    class MyCreateWithInlinesView (SuccessMessageMixin, CreateWithInlinesView):
+        success_message='Something was created!'
+    """
+
+    success_message = ""
+
+    def forms_valid(self, form, inlines):
+        response = super(SuccessMessageMixin, self).forms_valid(form, inlines)
+        success_message = self.get_success_message(form.cleaned_data, inlines)
+        if success_message:
+            messages.success(self.request, success_message)
+        return response
+
+    def get_success_message(self, cleaned_data, inlines):
+        return self.success_message % cleaned_data
+
+
+class FormSetSuccessMessageMixin(object):
+    """
+    Adds success message on FormSet views if django.contrib.messages framework
+    is used. In order to use just add mixin in to inheritance before main
+    class, e.g.:
+    class MyFormSetView (FormSetSuccessMessageMixin, ModelFormSetView):
+        success_message='Something was created!'
+    """
+
+    success_message = ""
+
+    def formset_valid(self, formset):
+        response = super(FormSetSuccessMessageMixin, self).formset_valid(formset)
+        success_message = self.get_success_message(formset)
+        if success_message:
+            messages.success(self.request, success_message)
+        return response
+
+    def get_success_message(self, formset):
+        return self.success_message
