@@ -1,11 +1,12 @@
 from django import forms
-from .models import Order, Item
+
+from .models import Item, Order
 
 
 class OrderForm(forms.ModelForm):
     class Meta:
         model = Order
-        fields = ['name']
+        fields = ["name"]
 
     def save(self, commit=True):
         instance = super(OrderForm, self).save(commit=commit)
@@ -22,7 +23,7 @@ class ItemForm(forms.ModelForm):
 
     class Meta:
         model = Item
-        fields = ['name', 'sku', 'price', 'order', 'status']
+        fields = ["name", "sku", "price", "order", "status"]
 
 
 class AddressForm(forms.Form):
